@@ -45,7 +45,6 @@ mod mul;
 mod mul_assign;
 mod neg;
 mod not;
-mod oppositive;
 mod ord;
 mod parity;
 mod partial_eq;
@@ -54,6 +53,7 @@ mod pow;
 mod rem;
 mod rem_assign;
 mod rem_euclid;
+mod signed;
 mod sub;
 mod sub_assign;
 mod to_bytes;
