@@ -1,18 +1,11 @@
 use std::ops::AddAssign;
 
-use crate::traits::{
-    AdditiveMonoid, DivisivePartialMagma, GcdMagma, MultiplicativeMonoid, Oppositive,
-};
+use crate::traits::{AdditiveMonoid, DivisivePartialMagma, GcdMagma, MultiplicativeMonoid, Signed};
 
 use super::types::{normalize_components_moduli, Fraction};
 
 impl<
-        Component: AdditiveMonoid
-            + Clone
-            + DivisivePartialMagma
-            + GcdMagma
-            + MultiplicativeMonoid
-            + Oppositive,
+        Component: AdditiveMonoid + Clone + DivisivePartialMagma + GcdMagma + MultiplicativeMonoid + Signed,
     > AddAssign for Fraction<Component>
 {
     fn add_assign(&mut self, other: Self) {
@@ -25,12 +18,7 @@ impl<
 }
 
 impl<
-        Component: AdditiveMonoid
-            + Clone
-            + DivisivePartialMagma
-            + GcdMagma
-            + MultiplicativeMonoid
-            + Oppositive,
+        Component: AdditiveMonoid + Clone + DivisivePartialMagma + GcdMagma + MultiplicativeMonoid + Signed,
     > AddAssign<Component> for Fraction<Component>
 {
     fn add_assign(&mut self, other: Component) {
