@@ -22,7 +22,6 @@ mod hash;
 mod mul;
 mod mul_assign;
 mod neg;
-mod oppositive;
 mod ord;
 mod partial_eq;
 mod partial_ord;
@@ -31,6 +30,7 @@ mod rem;
 mod rem_assign;
 mod rem_euclid;
 mod round;
+mod signed;
 mod sub;
 mod sub_assign;
 mod trunc;
