@@ -1,18 +1,13 @@
 use std::ops::SubAssign;
 
 use crate::traits::{
-    DivisivePartialMagma, GcdMagma, MultiplicativeMonoid, Oppositive, SubtractiveMagma,
+    DivisivePartialMagma, GcdMagma, MultiplicativeMonoid, Signed, SubtractiveMagma,
 };
 
 use super::types::{normalize_components_moduli, Fraction};
 
 impl<
-        Component: Clone
-            + DivisivePartialMagma
-            + GcdMagma
-            + Oppositive
-            + MultiplicativeMonoid
-            + SubtractiveMagma,
+        Component: Clone + DivisivePartialMagma + GcdMagma + Signed + MultiplicativeMonoid + SubtractiveMagma,
     > SubAssign for Fraction<Component>
 {
     fn sub_assign(&mut self, subtrahend: Self) {
@@ -25,12 +20,7 @@ impl<
 }
 
 impl<
-        Component: Clone
-            + DivisivePartialMagma
-            + GcdMagma
-            + Oppositive
-            + MultiplicativeMonoid
-            + SubtractiveMagma,
+        Component: Clone + DivisivePartialMagma + GcdMagma + Signed + MultiplicativeMonoid + SubtractiveMagma,
     > SubAssign<Component> for Fraction<Component>
 {
     fn sub_assign(&mut self, subtrahend: Component) {
