@@ -1124,7 +1124,7 @@ macro_rules! primitive_min_exp_impl {
 primitive_min_exp_impl!(f32 f64);
 
 pub trait Oppose {
-    type Result: Oppositive;
+    type Result: Signed;
 }
 
 impl Oppose for i8 {
@@ -1175,29 +1175,6 @@ impl Oppose for usize {
     type Result = isize;
 }
 
-pub trait Oppositive: NegatableUnaryAlgebra + Zeroable {
-    fn is_negative(&self) -> bool;
-    fn is_positive(&self) -> bool;
-}
-
-macro_rules! primitive_oppositive_impl {
-    ($($t:ty)*) => ($(
-        impl Oppositive for $t {
-            #[inline(always)]
-            fn is_negative(&self) -> bool {
-                <$t>::is_negative(*self)
-            }
-
-            #[inline(always)]
-            fn is_positive(&self) -> bool {
-                <$t>::is_positive(*self)
-            }
-        }
-    )*)
-}
-
-primitive_oppositive_impl!(i8 i16 i32 i64 i128 isize);
-
 pub trait Parity {
     fn is_even(&self) -> bool;
 
@@ -1264,7 +1241,7 @@ macro_rules! primitive_rem_euclid_impl {
 
 primitive_rem_euclid_impl!(i8 i16 i32 i64 i128 isize u8 u16 u32 u64 u128 usize);
 
-#[derive(Clone, Eq, PartialEq)]
+#[derive(Clone, Copy, Eq, PartialEq)]
 pub enum TieBreaking {
     AwayFromZero,
     ToEven,
@@ -1312,6 +1289,48 @@ macro_rules! primitive_round_impl {
 
 primitive_round_impl!(f32 f64);
 
+#[derive(Clone, Copy, Eq, PartialEq)]
+pub enum Sign {
+    Negative,
+    Zero,
+    Positive,
+}
+
+pub trait Signed: NegatableUnaryAlgebra + Zeroable {
+    fn is_negative(&self) -> bool;
+
+    fn is_positive(&self) -> bool;
+
+    #[inline(always)]
+    fn sign(&self) -> Sign {
+        if self.is_positive() {
+            Sign::Positive
+        } else if self.is_negative() {
+            Sign::Negative
+        } else {
+            Sign::Zero
+        }
+    }
+}
+
+macro_rules! primitive_signed_impl {
+    ($($t:ty)*) => ($(
+        impl Signed for $t {
+            #[inline(always)]
+            fn is_negative(&self) -> bool {
+                <$t>::is_negative(*self)
+            }
+
+            #[inline(always)]
+            fn is_positive(&self) -> bool {
+                <$t>::is_positive(*self)
+            }
+        }
+    )*)
+}
+
+primitive_signed_impl!(i8 i16 i32 i64 i128 isize);
+
 pub trait Trunc {
     type Output;
 
